package com.ruoyi.buyerapi.service;

import java.util.List;
import com.ruoyi.buyerapi.domain.BuyerProject;

/**
 * 立项管理Service接口
 *
 * @author ruoyi
 * @date 2022-09-22
 */
public interface IBuyerProjectService
{

    /**
     * 查询立项管理
     *
     * @param id 立项管理主键
     * @return 立项管理
     */
    public BuyerProject selectBuyerProjectById(String id);

    /**
     * 查询立项管理列表
     *
     * @param buyerProject 立项管理
     * @return 立项管理集合
     */
    public List<BuyerProject> selectBuyerProjectList(BuyerProject buyerProject);

    /**
     * 查询项目关联过程文件
     *
     * @param buyerProject 立项管理
     * @return 立项管理集合
     */
    public List<BuyerProject> selectBuyerProjectProcessFileList(BuyerProject buyerProject);

    /**
     * 查询项目关联过程文件
     *
     * @param buyerProject 立项管理
     * @return 立项管理集合
     */
    public List<BuyerProject> selectBuyerProjectAcceptFileList(BuyerProject buyerProject);

    /**
     * 查询立项管理列表
     *
     * @param buyerProject 立项管理
     * @return 立项管理集合
     */
    public List<BuyerProject> listForVoucher(BuyerProject buyerProject);

    /**
     * 新增立项管理
     *
     * @param buyerProject 立项管理
     * @return 结果
     */
    public int insertBuyerProject(BuyerProject buyerProject);

    /**
     * 修改立项管理
     *
     * @param buyerProject 立项管理
     * @return 结果
     */
    public int updateBuyerProject(BuyerProject buyerProject);

    /**
     * 批量删除立项管理
     *
     * @param ids 需要删除的立项管理主键集合
     * @return 结果
     */
    public int deleteBuyerProjectByIds(String[] ids);

    /**
     * 删除立项管理信息
     *
     * @param id 立项管理主键
     * @return 结果
     */
    public int deleteBuyerProjectById(String id);
}
